@@ -48,6 +48,7 @@ describe 'trove::guestagent' do
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('DEFAULT/swift_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_guestagent_config('DEFAULT/swift_service_type').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('DEFAULT/root_grant').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('DEFAULT/root_grant_option').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_guestagent_config('DEFAULT/default_password_length').with_value('<SERVICE DEFAULT>')
@@ -93,6 +94,17 @@ describe 'trove::guestagent' do
         end
       end
 
+      context 'when using default transport url' do
+        let :pre_condition do
+          "class { 'trove':
+             nova_proxy_admin_pass => 'verysecrete',
+             default_transport_url => 'rabbit://user:pass@host:1234/virt',}"
+        end
+        it 'configures trove-guestagent with DEFAULT/transport_url' do
+          is_expected.to contain_trove_guestagent_config('DEFAULT/transport_url').with_value('rabbit://user:pass@host:1234/virt')
+        end
+      end
+
     end
 
     context 'with custom parameters' do
@@ -104,6 +116,7 @@ describe 'trove::guestagent' do
       let :params do
         { :auth_url => "http://10.0.0.1:5000/v2.0",
           :swift_url => "http://10.0.0.1:8080/v1/AUTH_",
+          :swift_service_type => 'object-store',
           :rabbit_host => '10.1.0.1',
           :rabbit_port => '5673',
           :rabbit_use_ssl => 'true'
@@ -112,6 +125,7 @@ describe 'trove::guestagent' do
       it 'configures trove-guestagent with custom parameters' do
         is_expected.to contain_trove_guestagent_config('DEFAULT/trove_auth_url').with_value('http://10.0.0.1:5000/v2.0')
         is_expected.to contain_trove_guestagent_config('DEFAULT/swift_url').with_value('http://10.0.0.1:8080/v1/AUTH_')
+        is_expected.to contain_trove_guestagent_config('DEFAULT/swift_service_type').with_value('object-store')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_host').with_value('10.1.0.1')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_port').with_value('5673')
         is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
@@ -214,36 +228,26 @@ describe 'trove::guestagent' do
 
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily       => 'Debian',
-        :processorcount => 8
-      })
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      let(:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :guestagent_package_name => 'trove-guestagent',
+            :guestagent_service_name => 'trove-guestagent' }
+        when 'RedHat'
+          { :guestagent_package_name => 'openstack-trove-guestagent',
+            :guestagent_service_name => 'openstack-trove-guestagent' }
+        end
+      end
+      it_configures 'trove-guestagent'
     end
-
-    let :platform_params do
-      { :guestagent_package_name => 'trove-guestagent',
-        :guestagent_service_name => 'trove-guestagent' }
-    end
-
-    it_configures 'trove-guestagent'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily       => 'RedHat',
-        :processorcount => 8
-      })
-    end
-
-    let :platform_params do
-      { :guestagent_package_name => 'openstack-trove-guestagent',
-        :guestagent_service_name => 'openstack-trove-guestagent' }
-    end
-
-    it_configures 'trove-guestagent'
   end
 
 end
